@@ -1,5 +1,6 @@
 import React from "react";
 import ReactDOM from "react-dom";
+import "./app.css";
 import App from "./App";
 
-ReactDOM.render(<App />, document.getElementById('app'));
\ No newline at end of file
+ReactDOM.render(<App />, document.getElementById("app"));
