@@ -5,13 +5,11 @@ module.exports = {
 	},
 	purge: {
 		enabled: true,
-		content: [
-			"./resources/css/**/*.css",
-		],
+		content: ["./resources/css/**/*.css"],
 	},
 	theme: {
 		extend: {},
 	},
 	variants: {},
 	plugins: [],
-};
\ No newline at end of file
+};
